@@ -280,6 +280,6 @@ class __TwigTemplate_be5bf01cd8bbbef8042b62ea301bd605 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticLead/Timeline/_list.html.twig", "/var/www/mautic-ktn/app/bundles/LeadBundle/Resources/views/Timeline/_list.html.twig");
+        return new Source("", "@MauticLead/Timeline/_list.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Resources/views/Timeline/_list.html.twig");
     }
 }
