@@ -688,6 +688,6 @@ class AssetModel extends FormModel
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/AssetBundle/Model/AssetModel.php", "/var/www/mautic-ktn/app/bundles/AssetBundle/Model/AssetModel.php");
+        return new Source("", "@bundles/AssetBundle/Model/AssetModel.php", "/var/www/html/mauticGIT-Test/app/bundles/AssetBundle/Model/AssetModel.php");
     }
 }
