@@ -1097,6 +1097,6 @@ mautic.lead_list.filter.label.clonefilter=\"Clone filter\"";
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/LeadBundle/Translations/en_US/messages.ini", "/var/www/mautic-ktn/app/bundles/LeadBundle/Translations/en_US/messages.ini");
+        return new Source("", "@bundles/LeadBundle/Translations/en_US/messages.ini", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Translations/en_US/messages.ini");
     }
 }
