@@ -272,6 +272,6 @@ G";
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/fpoe_kaernten_theme_full_final_v2/assets/banner5.jpg", "/var/www/html/mauticGIT-Test/themes/fpoe_kaernten_theme_full_final_v2/assets/banner5.jpg");
+        return new Source("", "@themes/fpoe_kaernten_theme_full_final_v2/assets/banner5.jpg", "/var/www/mautic-ktn/themes/fpoe_kaernten_theme_full_final_v2/assets/banner5.jpg");
     }
 }
