@@ -330,6 +330,6 @@ class __TwigTemplate_0d4215ba7e31f5fb231d5bd1081a2e8f extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticPage/Page/_list.html.twig", "/var/www/mautic-ktn/app/bundles/PageBundle/Resources/views/Page/_list.html.twig");
+        return new Source("", "@MauticPage/Page/_list.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/PageBundle/Resources/views/Page/_list.html.twig");
     }
 }
