@@ -596,6 +596,6 @@ class StageController extends AbstractFormController
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/StageBundle/Controller/StageController.php", "/var/www/mautic-ktn/app/bundles/StageBundle/Controller/StageController.php");
+        return new Source("", "@bundles/StageBundle/Controller/StageController.php", "/var/www/html/mauticGIT-Test/app/bundles/StageBundle/Controller/StageController.php");
     }
 }
