@@ -380,6 +380,6 @@ class __TwigTemplate_27e5cbdb567cebb5424a1647cc092d3f extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/fresh-fixed/html/page.html.twig", "/var/www/mautic-ktn/themes/fresh-fixed/html/page.html.twig");
+        return new Source("", "@themes/fresh-fixed/html/page.html.twig", "/var/www/html/mauticGIT-Test/themes/fresh-fixed/html/page.html.twig");
     }
 }
