@@ -984,6 +984,6 @@ class __TwigTemplate_02dbfff736c6db3bbc0c75a358bd6373 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/sparse/html/email.html.twig", "/var/www/mautic-ktn/themes/sparse/html/email.html.twig");
+        return new Source("", "@themes/sparse/html/email.html.twig", "/var/www/html/mauticGIT-Test/themes/sparse/html/email.html.twig");
     }
 }
