@@ -724,6 +724,6 @@ class __TwigTemplate_34a05a01edd89cffa952d438ef8507ca extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/cards/html/email.html.twig", "/var/www/mautic-ktn/themes/cards/html/email.html.twig");
+        return new Source("", "@themes/cards/html/email.html.twig", "/var/www/html/mauticGIT-Test/themes/cards/html/email.html.twig");
     }
 }
