@@ -728,6 +728,6 @@ class __TwigTemplate_ab0ac05d7b51467a36892dc4d6d5c3b0 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/aurora/html/email.html.twig", "/var/www/mautic-ktn/themes/aurora/html/email.html.twig");
+        return new Source("", "@themes/aurora/html/email.html.twig", "/var/www/html/mauticGIT-Test/themes/aurora/html/email.html.twig");
     }
 }
