@@ -666,6 +666,6 @@ class CampaignRepository extends CommonRepository
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CampaignBundle/Entity/CampaignRepository.php", "/var/www/mautic-ktn/app/bundles/CampaignBundle/Entity/CampaignRepository.php");
+        return new Source("", "@bundles/CampaignBundle/Entity/CampaignRepository.php", "/var/www/html/mauticGIT-Test/app/bundles/CampaignBundle/Entity/CampaignRepository.php");
     }
 }
