@@ -651,6 +651,6 @@ class ChartQuery extends AbstractChart
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CoreBundle/Helper/Chart/ChartQuery.php", "/var/www/mautic-ktn/app/bundles/CoreBundle/Helper/Chart/ChartQuery.php");
+        return new Source("", "@bundles/CoreBundle/Helper/Chart/ChartQuery.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Helper/Chart/ChartQuery.php");
     }
 }
