@@ -293,6 +293,6 @@ class __TwigTemplate_0c7d99769af230ddbfb195a07c621965 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticLead/Lead/frequency.html.twig", "/var/www/mautic-ktn/app/bundles/LeadBundle/Resources/views/Lead/frequency.html.twig");
+        return new Source("", "@MauticLead/Lead/frequency.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Resources/views/Lead/frequency.html.twig");
     }
 }
