@@ -336,6 +336,6 @@ array_key_exists("customButtons", $context)) ? ((isset($context["customButtons"]
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticSms/Sms/details.html.twig", "/var/www/mautic-ktn/app/bundles/SmsBundle/Resources/views/Sms/details.html.twig");
+        return new Source("", "@MauticSms/Sms/details.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/SmsBundle/Resources/views/Sms/details.html.twig");
     }
 }
