@@ -678,6 +678,6 @@ class EventController extends CommonFormController
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CampaignBundle/Controller/EventController.php", "/var/www/mautic-ktn/app/bundles/CampaignBundle/Controller/EventController.php");
+        return new Source("", "@bundles/CampaignBundle/Controller/EventController.php", "/var/www/html/mauticGIT-Test/app/bundles/CampaignBundle/Controller/EventController.php");
     }
 }
