@@ -1050,6 +1050,6 @@ class ListController extends FormController
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/LeadBundle/Controller/ListController.php", "/var/www/mautic-ktn/app/bundles/LeadBundle/Controller/ListController.php");
+        return new Source("", "@bundles/LeadBundle/Controller/ListController.php", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Controller/ListController.php");
     }
 }
