@@ -1348,6 +1348,6 @@ body .facetwp-btn {
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/fresh-fixed/css/style.css", "/var/www/mautic-ktn/themes/fresh-fixed/css/style.css");
+        return new Source("", "@themes/fresh-fixed/css/style.css", "/var/www/html/mauticGIT-Test/themes/fresh-fixed/css/style.css");
     }
 }
