@@ -440,6 +440,6 @@ return [
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/IntegrationsBundle/Config/config.php", "/var/www/mautic-ktn/app/bundles/IntegrationsBundle/Config/config.php");
+        return new Source("", "@bundles/IntegrationsBundle/Config/config.php", "/var/www/html/mauticGIT-Test/app/bundles/IntegrationsBundle/Config/config.php");
     }
 }
