@@ -1000,6 +1000,6 @@ class __TwigTemplate_85f9efefd8b0ac622731de420ba74459 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/vibrant/html/email.html.twig", "/var/www/mautic-ktn/themes/vibrant/html/email.html.twig");
+        return new Source("", "@themes/vibrant/html/email.html.twig", "/var/www/html/mauticGIT-Test/themes/vibrant/html/email.html.twig");
     }
 }
